@@ -1,7 +1,7 @@
 #' @title Fit enrollment model
 #' @description Fits a specified enrollment model to the enrollment data.
 #'
-#' @param df The subject-level enrollment data, including
+#' @param df The subject-level enrollment data, including \code{trialsdt},
 #'   \code{randdt} and \code{cutoffdt}.
 #' @param enroll_model The enrollment model which can be specified as
 #'   "Poisson", "Time-decay", "B-spline", or
@@ -61,10 +61,11 @@ fitEnrollment <- function(df, enroll_model = "b-spline", nknots = 0,
 
   df <- dplyr::as_tibble(df)
   names(df) <- tolower(names(df))
+  df$trialsdt <- as.Date(df$trialsdt)
   df$randdt <- as.Date(df$randdt)
   df$cutoffdt <- as.Date(df$cutoffdt)
 
-  trialsdt = min(df$randdt)
+  trialsdt = df$trialsdt[1]
   cutoffdt = df$cutoffdt[1]
   n0 = nrow(df)
   # up to the last randomization date to account for enrollment completion
